@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
 
-from evalml.automl.utils import get_hyperparameter_ranges
 from evalml.exceptions import PipelineNotFoundError
 from evalml.tuners import SKOptTuner
 
@@ -12,7 +11,20 @@ class AutoMLAlgorithmException(Exception):
 
 
 class AutoMLAlgorithm(ABC):
-    """Base class for the automl algorithms which power evalml."""
+    """
+    Base class for the AutoML algorithms which power EvalML.
+
+    This class represents an automated machine learning (AutoML) algorithm. It encapsulates the decision-making logic behind an automl search, by both deciding which pipelines to evaluate next and by deciding what set of parameters to configure the pipeline with.
+
+    To use this interface, you must define a next_batch method which returns the next group of pipelines to evaluate on the training data. That method may access state and results recorded from the previous batches, although that information is not tracked in a general way in this base class. Overriding add_result is a convenient way to record pipeline evaluation info if necessary.
+
+    Arguments:
+        allowed_pipelines (list(class)): A list of PipelineBase subclasses indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
+        custom_hyperparameters (dict): Custom hyperparameter ranges specified for pipelines to iterate over.
+        max_iterations (int): The maximum number of iterations to be evaluated.
+        tuner_class (class): A subclass of Tuner, to be used to find parameters for each pipeline. The default of None indicates the SKOptTuner will be used.
+        random_seed (int): Seed for the random number generator. Defaults to 0.
+    """
 
     def __init__(
         self,
@@ -22,25 +34,14 @@ class AutoMLAlgorithm(ABC):
         tuner_class=None,
         random_seed=0,
     ):
-        """This class represents an automated machine learning (AutoML) algorithm. It encapsulates the decision-making logic behind an automl search, by both deciding which pipelines to evaluate next and by deciding what set of parameters to configure the pipeline with.
-
-        To use this interface, you must define a next_batch method which returns the next group of pipelines to evaluate on the training data. That method may access state and results recorded from the previous batches, although that information is not tracked in a general way in this base class. Overriding add_result is a convenient way to record pipeline evaluation info if necessary.
-
-        Arguments:
-            allowed_pipelines (list(class)): A list of PipelineBase subclasses indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
-            custom_hyperparameters (dict): Custom hyperparameter ranges specified for pipelines to iterate over.
-            max_iterations (int): The maximum number of iterations to be evaluated.
-            tuner_class (class): A subclass of Tuner, to be used to find parameters for each pipeline. The default of None indicates the SKOptTuner will be used.
-            random_seed (int): Seed for the random number generator. Defaults to 0.
-        """
         self.random_seed = random_seed
         self.allowed_pipelines = allowed_pipelines or []
         self.max_iterations = max_iterations
         self._tuner_class = tuner_class or SKOptTuner
         self._tuners = {}
         for pipeline in self.allowed_pipelines:
-            pipeline_hyperparameters = get_hyperparameter_ranges(
-                pipeline.component_graph, custom_hyperparameters
+            pipeline_hyperparameters = pipeline.get_hyperparameter_ranges(
+                custom_hyperparameters
             )
             self._tuners[pipeline.name] = self._tuner_class(
                 pipeline_hyperparameters, random_seed=self.random_seed
