@@ -1,4 +1,3 @@
-import copy
 from collections import namedtuple
 
 import pandas as pd
@@ -7,7 +6,6 @@ from sklearn.model_selection import KFold, StratifiedKFold
 from evalml.objectives import get_objective
 from evalml.pipelines import (
     BinaryClassificationPipeline,
-    ComponentGraph,
     MulticlassClassificationPipeline,
     RegressionPipeline,
     TimeSeriesBinaryClassificationPipeline,
@@ -207,29 +205,6 @@ def get_best_sampler_for_data(X, y, sampler_method, sampler_balanced_ratio):
             return "Undersampler"
 
 
-def get_hyperparameter_ranges(component_graph, custom_hyperparameters):
-    """
-    Returns hyperparameter ranges from all components as a dictionary.
-
-    Arguments:
-        component_graph (list(str, ComponentBase)): The component_graph of the pipeline.
-        custom_hyperparameters (dict): The custom hyperparameters to be passed to the pipeline.
-
-    Returns:
-        dict: Dictionary of hyperparameter ranges for each component in the component graph.
-    """
-    linearized_component_graph = ComponentGraph.linearized_component_graph(
-        component_graph
-    )
-    hyperparameter_ranges = dict()
-    for component_name, component_class in linearized_component_graph:
-        component_hyperparameters = copy.copy(component_class.hyperparameter_ranges)
-        if custom_hyperparameters and component_name in custom_hyperparameters:
-            component_hyperparameters.update(custom_hyperparameters[component_name])
-        hyperparameter_ranges[component_name] = component_hyperparameters
-    return hyperparameter_ranges
-
-
 def get_pipelines_from_component_graphs(
     component_graphs_dict, problem_type, parameters=None, random_seed=0
 ):
