@@ -9,21 +9,28 @@ from evalml.utils import infer_feature_types
 
 
 class HighlyNullDataCheck(DataCheck):
-    """Checks if there are any highly-null columns and rows in the input."""
+    """Checks if there are any highly-null columns and rows in the input.
 
-    def __init__(self, pct_null_threshold=0.95):
-        """Checks if there are any highly-null columns and rows in the input.
+    Arguments:
+        pct_null_col_threshold(float): If the percentage of NaN values in an input feature exceeds this amount,
+            that column will be considered highly-null. Defaults to 0.95.
+        pct_null_row_threshold(float): If the percentage of NaN values in an input row exceeds this amount,
+            that row will be considered highly-null. Defaults to 0.95.
 
-        Arguments:
-            pct_null_threshold(float): If the percentage of NaN values in an input feature exceeds this amount,
-                that column/row will be considered highly-null. Defaults to 0.95.
+    """
 
-        """
-        if pct_null_threshold < 0 or pct_null_threshold > 1:
+    def __init__(self, pct_null_col_threshold=0.95, pct_null_row_threshold=0.95):
+        if pct_null_col_threshold < 0 or pct_null_col_threshold > 1:
             raise ValueError(
-                "pct_null_threshold must be a float between 0 and 1, inclusive."
+                "pct null column threshold must be a float between 0 and 1, inclusive."
             )
-        self.pct_null_threshold = pct_null_threshold
+        if pct_null_row_threshold < 0 or pct_null_row_threshold > 1:
+            raise ValueError(
+                "pct null row threshold must be a float between 0 and 1, inclusive."
+            )
+
+        self.pct_null_col_threshold = pct_null_col_threshold
+        self.pct_null_row_threshold = pct_null_row_threshold
 
     def validate(self, X, y=None):
         """Checks if there are any highly-null columns or rows in the input.
@@ -48,7 +55,7 @@ class HighlyNullDataCheck(DataCheck):
             ...    'lots_of_null': [None, None, None, None, 5],
             ...    'no_null': [1, 2, 3, 4, 5]
             ... })
-            >>> null_check = HighlyNullDataCheck(pct_null_threshold=0.50)
+            >>> null_check = HighlyNullDataCheck(pct_null_col_threshold=0.50, pct_null_row_threshold=0.50)
             >>> validation_results = null_check.validate(df)
             >>> validation_results['warnings'][0]['details']['pct_null_cols'] = SeriesWrap(validation_results['warnings'][0]['details']['pct_null_cols'])
             >>> highly_null_rows = SeriesWrap(pd.Series([0.5, 0.5, 0.5, 0.5]))
@@ -74,10 +81,10 @@ class HighlyNullDataCheck(DataCheck):
 
         percent_null_rows = X.isnull().mean(axis=1)
         highly_null_rows = percent_null_rows[
-            percent_null_rows >= self.pct_null_threshold
+            percent_null_rows >= self.pct_null_row_threshold
         ]
         if len(highly_null_rows) > 0:
-            warning_msg = f"{len(highly_null_rows)} out of {len(X)} rows are more than {self.pct_null_threshold*100}% null"
+            warning_msg = f"{len(highly_null_rows)} out of {len(X)} rows are more than {self.pct_null_row_threshold*100}% null"
             results["warnings"].append(
                 DataCheckWarning(
                     message=warning_msg,
@@ -97,13 +104,15 @@ class HighlyNullDataCheck(DataCheck):
         highly_null_cols = {
             key: value
             for key, value in percent_null_cols.items()
-            if value >= self.pct_null_threshold and value != 0
+            if value >= self.pct_null_col_threshold and value != 0
         }
         warning_msg = "Column '{}' is {}% or more null"
         results["warnings"].extend(
             [
                 DataCheckWarning(
-                    message=warning_msg.format(col_name, self.pct_null_threshold * 100),
+                    message=warning_msg.format(
+                        col_name, self.pct_null_col_threshold * 100
+                    ),
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.HIGHLY_NULL_COLS,
                     details={
