@@ -12,19 +12,19 @@ warning_too_unique = "Input columns ({}) for {} problem type are too sparse."
 
 
 class SparsityDataCheck(DataCheck):
-    """Checks if there are any columns with sparsely populated values in the input."""
+    """Checks if there are any columns with sparsely populated values in the input.
+
+    Arguments:
+        problem_type (str or ProblemTypes): The specific problem type to data check for.
+            'multiclass' or 'time series multiclass' is the only accepted problem type.
+        threshold (float): The threshold value, or percentage of each column's unique values,
+            below which, a column exhibits sparsity.  Should be between 0 and 1.
+        unique_count_threshold (int): The minimum number of times a unique
+            value has to be present in a column to not be considered "sparse."
+            Defaults to 10.
+    """
 
     def __init__(self, problem_type, threshold, unique_count_threshold=10):
-        """Checks each column in the input to determine the sparsity of the values in those columns.
-        Arguments:
-            problem_type (str or ProblemTypes): The specific problem type to data check for.
-                'multiclass' or 'time series multiclass' is the only accepted problem type.
-            threshold (float): The threshold value, or percentage of each column's unique values,
-                below which, a column exhibits sparsity.  Should be between 0 and 1.
-            unique_count_threshold (int): The minimum number of times a unique
-                value has to be present in a column to not be considered "sparse."
-                Default is 10.
-        """
         self.problem_type = handle_problem_types(problem_type)
         if not is_multiclass(self.problem_type):
             raise ValueError("Sparsity is only defined for multiclass problem types.")
@@ -38,11 +38,14 @@ class SparsityDataCheck(DataCheck):
     def validate(self, X, y=None):
         """Calculates what percentage of each column's unique values exceed the count threshold and compare
         that percentage to the sparsity threshold stored in the class instance.
+
         Arguments:
             X (pd.DataFrame, np.ndarray): Features.
             y (pd.Series, np.ndarray): Ignored.
+
         Returns:
             dict: dict with a DataCheckWarning if there are any sparse columns.
+
         Example:
             >>> import pandas as pd
             >>> df = pd.DataFrame({
@@ -94,10 +97,12 @@ class SparsityDataCheck(DataCheck):
     def sparsity_score(col, count_threshold=10):
         """This function calculates a sparsity score for the given value counts by calculating the percentage of
         unique values that exceed the count_threshold.
+
         Arguments:
             col (pd.Series): Feature values.
             count_threshold (int): The number of instances below which a value is considered sparse.
                 Default is 10.
+
         Returns:
             (float): Sparsity score, or the percentage of the unique values that exceed count_threshold.
         """
